#
# (C) COPYRIGHT 2020, Joao Luiz Elias Campos.
# All Rights Reserved
# Duplication of this program or any part thereof without the express
# written consent of the author is prohibited
#

#' @file colormap.R
#' @author Joao Luiz Elias Campos \email{jlecampos@gmail.com}
#' @date April 26, 2020

colormap = function(name='hspe',alpha=1)
{
  na.approx = function(x) {
    idx = which(!is.na(x))
    for(i in 1:(length(idx)-1)) {
      len = idx[i+1]-idx[i]
      if(len > 1) {
        vlo = x[idx[i]]
        vhi = x[idx[i+1]]
        dx = (vhi-vlo)/len
        for(j in (idx[i]+1):(idx[i+1]-1)) {
          vlo = vlo+dx
          x[j] = vlo
        }
      }
    }
    return(x)
  }

  cmap = read.table(paste0('colormaps/',name,'.cmap'))
  colnames(cmap) = c('N','R','G','B')

  crgb = data.frame(R=rep(NA,256),G=rep(NA,256),B=rep(NA,256))
  crgb$R[cmap$N+1] = cmap$R
  crgb$G[cmap$N+1] = cmap$G
  crgb$B[cmap$N+1] = cmap$B
  c = rgb(na.approx(crgb$R),na.approx(crgb$G),na.approx(crgb$B))
  if(alpha < 1) {
    c = adjustcolor(c,alpha.f=alpha)
  }
  return(c)
}

encode = function(r,g,b) {
  rv = bitwShiftL(bitwAnd(r,0xff),16)
  gv = bitwShiftL(bitwAnd(g,0xff),8)
  bv = bitwAnd(b,0xff)
  return(bitwOr(rv,bitwOr(gv,bv)))
}

# End of File

