#
# (C) COPYRIGHT 2020, Joao Luiz Elias Campos.
# All Rights Reserved
# Duplication of this program or any part thereof without the express
# written consent of the author is prohibited
#

#' @file mimage.R
#' @author Joao Luiz Elias Campos \email{jlecampos@gmail.com}
#' @date May 01, 2020

mimage = function(x,col=hcl.colors(12,"YlOrRd",rev=TRUE),scale=FALSE,...) {
  wv = 1:ncol(x)
  hv = 1:nrow(x)
  zv = range(x[is.finite(x)])

  nc = length(col)
  z = (x - zv[1])/diff(zv)
  zi = floor((nc - 1e-5) * z + 1e-7)
  zi[zi < 0 | zi >= nc] = NA

  if(scale) {
    opar = par(no.readonly=TRUE)
    layout(matrix(c(1,2),nrow=1,ncol=2),widths=c(8,1),heights=c(4))
    par(mar=c(1,4,4,1))
  }
  
  plot(range(wv),range(hv),xlim=c(1,ncol(x)),ylim=c(nrow(x),1),type='n',
       xaxs="i",yaxs="i",xaxt='n',ylab='pixel')
  axis(3)
  mtext('pixel',line=2.5)

  zc = col[zi+1]
  dim(zc) = dim(z)
  zc = zc[nrow(zc):1,]
  rasterImage(as.raster(zc),min(wv),min(hv),max(wv),max(hv),
              interpolate=FALSE)

  if(scale) {
    par(mar=c(1,0,4,2.5))
    breaks = seq(zv[1],zv[2],length.out=(length(col)+1))
    poly = vector(mode="list",length(col))
    for(i in seq(poly)) {
      poly[[i]] = c(breaks[i],breaks[i+1],breaks[i+1],breaks[i])
    }

    ylim = range(breaks)
    xlim = c(0,1)
    plot(1,1,type='n',ylim=ylim,xlim=xlim,axes=FALSE,xlab=NA,ylab=NA,
         xaxs="i",yaxs="i",...)
    axis(4)
    for(i in seq(poly)) {
      polygon(c(0,0,1,1),poly[[i]],col=col[i],border=NA)
    }
    box()
    par(opar)
  }
  invisible()
}

# End of File

